
### 12/09/2018- Worldclim and elevation data processing and correlation script ###
## Sarah A. Scriven ##

# Install packages
library (raster)
library (sp)
library (rgdal)    
library (maptools) 


#######################
## 1. Elevation data ##
#######################

## Nb: Elevation data were downloaded directly from the CGIAR-CSI GeoPortal (http://srtm.csi.cgiar.org/; [accessed October 1st 2018]) at 250 m resolution.
## Data were then projected into "WGS_1984_UTM_Zone_50N" at a 1 km resolution and cropped for Borneo. See code below: 
## Shapefiles for each country can be downloaded from: https://gadm.org/maps.html.   

setwd("D:/Rainforest Trust Project/SDM Biotropica Manuscript/STRMElevationData")
elevation250m <- raster ("elevation250m.tif") # Load the elevation data 
plot (elevation250m) # This may take a while

setwd ("D:/Rainforest Trust Project/Species Distribution R Code/AllBorneo990mSDMs") 
BorneoBuff100km <- readOGR("BorneoBuff100mProject.shp") # Load Borneo shapefile with a 100km buffer (nb: this file is not provided in the zip folder, but can be created by merging country files and adding a buffer)
plot(BorneoBuff100km)
BorneoBuff100km<- spTransform(BorneoBuff100km, CRS("+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0")) # Project Borneo shapefile

Elevation250mBorneo<- mask (elevation250m, BorneoBuff100km)  # Use 'mask' function to mask out grid-cells that are not in Borneo, this may take a few minutes 
plot (Elevation250mBorneo)
Elevation250mBorneo<- crop (Elevation250mBorneo, BorneoBuff100km)  # Use 'crop' function to crop the layer to only include the extent for Borneo
plot (Elevation250mBorneo)         
plot (BorneoBuff100km, add=T)        
writeRaster(Elevation250mBorneo, filename="Elevation250mBorneo", overwrite=TRUE) # Save this new layer as a .tif file in your working directory folder

newproj<- "+proj=utm +zone=50 +ellps=WGS84 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs" # Set the projection 
Elevation1kmBorneo<- projectRaster (Elevation250mBorneo, crs=newproj, res=1000) # Change to 1 km resolution
writeRaster(Elevation1kmBorneo, filename="Elevation1kmBorneo_utm50", overwrite=TRUE) 


##############################
## 2. Worldclim data layers ##
##############################

## Nb: Climate variables for 1970-2000 were downloaded directly from the Worldclim database (http://worldclim.org/version2 [accessed June 9th 2018]) at ~1 km2 (30 arc-second) resolution.
## They were then projected into "WGS_1984_UTM_Zone_50N" at a 1 km resolution and cropped for Borneo. See code below: 

setwd("D:/Rainforest Trust Project/SDM Biotropica Manuscript/BioclimVariables1km/wc2.0_30s_bio")
Bio1 <- raster("wc2.0_bio_30s_01.tif")  # BIO1 = Annual Mean Temperature
Bio2 <- raster("wc2.0_bio_30s_02.tif")  # BIO2 = Mean Diurnal Range (Mean of monthly (max temp - min temp)) 
Bio3 <- raster("wc2.0_bio_30s_03.tif")  # BIO3 = Isothermality (BIO2/BIO7) (* 100)
Bio4 <- raster("wc2.0_bio_30s_04.tif")  # BIO4 = Temperature Seasonality (standard deviation *100)
Bio5 <- raster("wc2.0_bio_30s_05.tif")  # BIO5 = Max Temperature of Warmest Month
Bio6 <- raster("wc2.0_bio_30s_06.tif")  # BIO6 = Min Temperature of Coldest Month
Bio7 <- raster("wc2.0_bio_30s_07.tif")  # BIO7 = Temperature Annual Range (BIO5-BIO6)
Bio8 <- raster("wc2.0_bio_30s_08.tif")  # BIO8 = Mean Temperature of Wettest Quarter
Bio9 <- raster("wc2.0_bio_30s_09.tif")  # BIO9 = Mean Temperature of Driest Quarter
Bio10 <- raster("wc2.0_bio_30s_10.tif") # BIO10 = Mean Temperature of Warmest Quarter
Bio11 <- raster("wc2.0_bio_30s_11.tif") # BIO11 = Mean Temperature of Coldest Quarter
Bio12 <- raster("wc2.0_bio_30s_12.tif") # BIO12 = Annual Precipitation
Bio13 <- raster("wc2.0_bio_30s_13.tif") # BIO13 = Precipitation of Wettest Month
Bio14 <- raster("wc2.0_bio_30s_14.tif") # BIO14 = Precipitation of Driest Month
Bio15 <- raster("wc2.0_bio_30s_15.tif") # BIO15 = Precipitation Seasonality (Coefficient of Variation)
Bio16 <- raster("wc2.0_bio_30s_16.tif") # BIO16 = Precipitation of Wettest Quarter
Bio17 <- raster("wc2.0_bio_30s_17.tif") # BIO17 = Precipitation of Driest Quarter
Bio18 <- raster("wc2.0_bio_30s_18.tif") # BIO18 = Precipitation of Warmest Quarter
Bio19 <- raster("wc2.0_bio_30s_19.tif") # BIO19 = Precipitation of Coldest Quarter

# Extract climate data for Borneo at 30 arc seconds 
Bio1Borneo<- mask(Bio1, BorneoBuff100km) # Use 'mask' function to mask out grid-cells that are not in Borneo, this may take up to 10 mins per layer
Bio2Borneo<- mask(Bio2, BorneoBuff100km) 
Bio3Borneo<- mask(Bio3, BorneoBuff100km)
Bio4Borneo<- mask(Bio4, BorneoBuff100km)
Bio5Borneo<- mask(Bio5, BorneoBuff100km)
Bio6Borneo<- mask(Bio6, BorneoBuff100km)
Bio7Borneo<- mask(Bio7, BorneoBuff100km)
Bio8Borneo<- mask(Bio8, BorneoBuff100km)
Bio9Borneo<- mask(Bio9, BorneoBuff100km) 
Bio10Borneo<- mask(Bio10, BorneoBuff100km)
Bio11Borneo<- mask(Bio11, BorneoBuff100km)
Bio12Borneo<- mask(Bio12, BorneoBuff100km)
Bio13Borneo<- mask(Bio13, BorneoBuff100km)
Bio14Borneo<- mask(Bio14, BorneoBuff100km)
Bio15Borneo<- mask(Bio15, BorneoBuff100km)
Bio16Borneo<- mask(Bio16, BorneoBuff100km)
Bio17Borneo<- mask(Bio17, BorneoBuff100km)
Bio18Borneo<- mask(Bio18, BorneoBuff100km)
Bio19Borneo<- mask(Bio19, BorneoBuff100km)


## Crop the data for Borneo
Bio1BorneoC<-crop(Bio1Borneo, extent(BorneoBuff100km)) # Now use 'crop' to crop the layer to only include the extent for Borneo
Bio2BorneoC<-crop(Bio2Borneo, extent(BorneoBuff100km))
Bio3BorneoC<-crop(Bio3Borneo, extent(BorneoBuff100km))
Bio4BorneoC<-crop(Bio4Borneo, extent(BorneoBuff100km))
Bio5BorneoC<-crop(Bio5Borneo, extent(BorneoBuff100km))
Bio6BorneoC<-crop(Bio6Borneo, extent(BorneoBuff100km))
Bio7BorneoC<-crop(Bio7Borneo, extent(BorneoBuff100km))
Bio8BorneoC<-crop(Bio8Borneo, extent(BorneoBuff100km))
Bio9BorneoC<-crop(Bio9Borneo, extent(BorneoBuff100km))
Bio10BorneoC<-crop(Bio10Borneo, extent(BorneoBuff100km))
Bio11BorneoC<-crop(Bio11Borneo, extent(BorneoBuff100km))
Bio12BorneoC<-crop(Bio12Borneo, extent(BorneoBuff100km))
Bio13BorneoC<-crop(Bio13Borneo, extent(BorneoBuff100km))
Bio14BorneoC<-crop(Bio14Borneo, extent(BorneoBuff100km))
Bio15BorneoC<-crop(Bio15Borneo, extent(BorneoBuff100km))
Bio16BorneoC<-crop(Bio16Borneo, extent(BorneoBuff100km))
Bio17BorneoC<-crop(Bio17Borneo, extent(BorneoBuff100km))
Bio18BorneoC<-crop(Bio18Borneo, extent(BorneoBuff100km))
Bio19BorneoC<-crop(Bio19Borneo, extent(BorneoBuff100km))


# Reproject the bioclimatic variables to 1 km resolution
Elevation1kmBorneo # Check the CRS of the Elevation data 
#newproj<- "+proj=utm +zone=50 +ellps=WGS84 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"

# The 19x Climate layers 
Bio1BorP1000m<- projectRaster(Bio1BorneoC, crs=newproj, res=1000) # Change to 1 km resolution
Bio2BorP1000m<- projectRaster(Bio2BorneoC, crs=newproj, res=1000)  
Bio3BorP1000m<- projectRaster(Bio3BorneoC, crs=newproj, res=1000)  
Bio4BorP1000m<- projectRaster(Bio4BorneoC, crs=newproj, res=1000)  
Bio5BorP1000m<- projectRaster(Bio5BorneoC, crs=newproj, res=1000)  
Bio6BorP1000m<- projectRaster(Bio6BorneoC, crs=newproj, res=1000) 
Bio7BorP1000m<- projectRaster(Bio7BorneoC, crs=newproj, res=1000)  
Bio8BorP1000m<- projectRaster(Bio8BorneoC, crs=newproj, res=1000)  
Bio9BorP1000m<- projectRaster(Bio9BorneoC, crs=newproj, res=1000)  
Bio10BorP1000m<- projectRaster(Bio10BorneoC, crs=newproj, res=1000)  
Bio11BorP1000m<- projectRaster(Bio11BorneoC, crs=newproj, res=1000)  
Bio12BorP1000m<- projectRaster(Bio12BorneoC, crs=newproj, res=1000)  
Bio13BorP1000m<- projectRaster(Bio13BorneoC, crs=newproj, res=1000)  
Bio14BorP1000m<- projectRaster(Bio14BorneoC, crs=newproj, res=1000)  
Bio15BorP1000m<- projectRaster(Bio15BorneoC, crs=newproj, res=1000)  
Bio16BorP1000m<- projectRaster(Bio16BorneoC, crs=newproj, res=1000)  
Bio17BorP1000m<- projectRaster(Bio17BorneoC, crs=newproj, res=1000)  
Bio18BorP1000m<- projectRaster(Bio18BorneoC, crs=newproj, res=1000)  
Bio19BorP1000m<- projectRaster(Bio19BorneoC, crs=newproj, res=1000) 

Elevation1kmBorneoR <- resample(Elevation1kmBorneo, Bio1BorP1000m, "bilinear") # Resample "Elevation1kmBorneo" layer to be the same as "Bio1SabP" layer 

# Export WorldClim variables to rasters: 1km, UTM 50N
setwd("D:/Rainforest Trust Project/SDM Biotropica Manuscript/BioclimVariables1km/Borneo1km100kmBuf_UTM50N")
writeRaster(Bio1BorP1000m, filename="AnnualMeanTempBorneo1km", overwrite=TRUE)
writeRaster(Bio2BorP1000m, filename="MeanDiurnalRangeBorneo1km", overwrite=TRUE)  
writeRaster(Bio3BorP1000m, filename="IsothermalityBorneo1km", overwrite=TRUE)  
writeRaster(Bio4BorP1000m, filename="TemperatureSeasonalityBorneo1km", overwrite=TRUE)  
writeRaster(Bio5BorP1000m, filename="MaxTempWarmestMonthBorneo1km", overwrite=TRUE)  
writeRaster(Bio6BorP1000m, filename="MinTempColdestMonthBorneo1km", overwrite=TRUE) 
writeRaster(Bio7BorP1000m, filename="TempAnnualRangeBorneo1km",  overwrite=TRUE)  
writeRaster(Bio8BorP1000m, filename="MeanTempWettestQuarterBorneo1km", overwrite=TRUE)  
writeRaster(Bio9BorP1000m, filename="MeanTempDriestQuarterBorneo1km", overwrite=TRUE)  
writeRaster(Bio10BorP1000m, filename="MeanTempWarmestQuarterBorneo1km", overwrite=TRUE)  
writeRaster(Bio11BorP1000m, filename="MeanTempColdestQuarterBorneo1km", overwrite=TRUE)  
writeRaster(Bio12BorP1000m, filename="AnnualPrecipBorneo1km", overwrite=TRUE)  
writeRaster(Bio13BorP1000m, filename="PrecipWettestMonthBorneo10km", overwrite=TRUE)  
writeRaster(Bio14BorP1000m, filename="PrecipDriestMonthBorneo10km", overwrite=TRUE)  
writeRaster(Bio15BorP1000m, filename="PrecipSeasonalityBorneo1km", overwrite=TRUE)  
writeRaster(Bio16BorP1000m, filename="PrecipWettestQuarterBorneo1km", overwrite=TRUE)  
writeRaster(Bio17BorP1000m, filename="PrecipDriestQuarterBorneo1km", overwrite=TRUE)  
writeRaster(Bio18BorP1000m, filename="PrecipWarmestQuarterBorneo1km", overwrite=TRUE)  
writeRaster(Bio19BorP1000m, filename="PrecipColdestQuarterBorneo1km", overwrite=TRUE) 
writeRaster (Elevation1kmBorneoR , filename="ElevationBorneo1km", overwrite=TRUE)  


#############################################################
## 3. Stack the variables and perform correlation analysis ##
#############################################################

VariableStack<- stack(Elevation1kmBorneoR, Bio1BorP1000m, Bio2BorP1000m, Bio3BorP1000m, Bio4BorP1000m, Bio5BorP1000m, Bio6BorP1000m, Bio7BorP1000m, Bio8BorP1000m, Bio9BorP1000m,  
		          Bio10BorP1000m, Bio11BorP1000m, Bio12BorP1000m, Bio13BorP1000m, Bio14BorP1000m, Bio15BorP1000m, Bio16BorP1000m, Bio17BorP1000m, Bio18BorP1000m, Bio19BorP1000m)  

hist (Bio1BorP1000m) # Examine histograms to check for normal distribution. Data don't all appear to be normally distributed. Hence, use Spearman's rank for correlation analysis 

## Spearman's rank ## 

vals <- values (VariableStack)
valsdf<-data.frame (vals)
head (valsdf)
length (vals)
summary (vals)

corr_matrixSp<-cor(valsdf, method='spearman', use = "complete.obs") # Table of Spearman's correlation coefficients
write.csv(corr_matrixSp, file = "SpearmanCorrelations1000m.csv") 
# Values over >0.7 are relatively correlated; if we used this value as a cutoff threshold the final subset of variables to use in the SDMs are:
	# 1. "Bio1BorP1000m" - Annual mean temp 
	# 2. "Bio2BorP1000m" - Mean diurnal temperature range 
	# 3. "Bio4BorP1000m" - Temperature seasonality 
	# 4. "Bio14BorP1000m" - Precipitation of the driest month 
	# 5. "Bio16BorP1000m" - Precipitation of the wettest quarter  

 